==> kernel-1.1.5.3-sources.jar: voxeet/com/sdk/json/DeviceEvent.java <==
package voxeet.com.sdk.json;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeName;

import java.util.HashMap;

import voxeet.com.sdk.json.internal.MetadataHolder;
import voxeet.com.sdk.networking.DeviceType;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonTypeName(EventNames.DEVICE_TYPE)
public class DeviceEvent extends Event {

    @JsonProperty("device_type")
    private DeviceType deviceType;

    @JsonProperty("sdp_version")
    private String sdpVersion;

    @JsonProperty("participantType")
    private String participantType;

    @JsonProperty("metadata")
    private MetadataHolder metadata;

    public DeviceEvent() {
        metadata = new MetadataHolder();
        metadata.setStats(true);
    }

    public DeviceEvent(DeviceType deviceType, boolean listenerMode) {
        this();
        this.deviceType = deviceType;

        this.sdpVersion = "SDP_V2";

        if (listenerMode)
            this.participantType = "LISTENER";
        else
            this.participantType = "USER";
    }

    public String getParticipantType() {
        return participantType;
    }

    public void setParticipantType(String participantType) {
        this.participantType = participantType;
    }

    public String getSdpVersion() {
        return sdpVersion;
    }

    public void setSdpVersion(String sdpVersion) {
        this.sdpVersion = sdpVersion;
    }

    public DeviceType getDeviceType() {
        return deviceType;
    }

    public void setDeviceType(DeviceType deviceType) {
        this.deviceType = deviceType;
    }

    @Override
    public String getType() {
        return EventNames.DEVICE_TYPE;
    }
}

==> kernel-1.1.8.41-sources.jar: voxeet/com/sdk/json/DeviceEvent.java <==
package voxeet.com.sdk.json;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeName;

import java.util.HashMap;

import voxeet.com.sdk.json.internal.MetadataHolder;
import voxeet.com.sdk.networking.DeviceType;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonTypeName(EventNames.DEVICE_TYPE)
public class DeviceEvent extends Event {

    @JsonProperty("device_type")
    private DeviceType deviceType;

    @JsonProperty("sdp_version")
    private String sdpVersion;

    @JsonProperty("participantType")
    private String participantType;

    @JsonProperty("metadata")
    private HashMap<String, Object> metadata;

    public DeviceEvent() {
        metadata = new HashMap<>();
        //metadata.setStats(true);
    }

    public DeviceEvent(DeviceType deviceType, boolean listenerMode) {
        this();
        this.deviceType = deviceType;

        this.sdpVersion = "SDP_V2";

        if (listenerMode)
            this.participantType = "LISTENER";
        else
            this.participantType = "USER";
    }

    public String getParticipantType() {
        return participantType;
    }

    public void setParticipantType(String participantType) {
        this.participantType = participantType;
    }

    public String getSdpVersion() {
        return sdpVersion;
    }

    public void setSdpVersion(String sdpVersion) {
        this.sdpVersion = sdpVersion;
    }

    public DeviceType getDeviceType() {
        return deviceType;
    }

    public void setDeviceType(DeviceType deviceType) {
        this.deviceType = deviceType;
    }

    @Override
    public String getType() {
        return EventNames.DEVICE_TYPE;
    }
}
